package com.dragoninfo.dcuc.authweb.restcontroller.element;

import com.dragoninfo.dcuc.auth.element.facade.IEnvElementFacade;
import com.dragoninfo.dcuc.auth.element.vo.EnvElementSaveVo;
import com.dragoninfo.dcuc.auth.element.vo.RespEnvElementVo;
import com.dragoninfo.duceap.core.response.Result;
import com.dragonsoft.duceap.base.entity.http.ResponseStatus;
import com.dragonsoft.duceap.base.entity.search.SearchDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @author mazq
 * @date 2022/8/25
 */
@RestController
@RequestMapping("/envElement")
public class EnvElementController {

    @Autowired
    private IEnvElementFacade envElementFacade;

    @GetMapping("getById/{id}")
    public Result<RespEnvElementVo> getById(@PathVariable("id") String id) {
        RespEnvElementVo vo = envElementFacade.getById(id);
        return Result.success(vo);
    }

    @PostMapping("search")
    public Result<List<RespEnvElementVo>> pageSearch(SearchDTO searchDTO) {
        Page<RespEnvElementVo> page = envElementFacade.pageSearch(searchDTO);
        return Result.success(page.getTotalElements(), page.getContent());
    }

    @PostMapping("save")
    public Result save(@RequestBody EnvElementSaveVo envElementVo) {
       ResponseStatus responseStatus = envElementFacade.save(envElementVo);
        return getResult(responseStatus);
    }

    @PostMapping("update")
    public Result update(@RequestBody EnvElementSaveVo envElementVo) {
        ResponseStatus responseStatus = envElementFacade.update(envElementVo);
        return getResult(responseStatus);
    }

    @DeleteMapping("deleteById/{id}")
    public Result deleteById(@PathVariable("id") String id) {
        ResponseStatus responseStatus = envElementFacade.deleteById(id);
        return getResult(responseStatus);
    }

    private Result getResult(ResponseStatus responseStatus) {
        Result result = new Result();
        result.setMsg(responseStatus.getMessage());
        result.setResult(responseStatus.getStatusCode());
        return result;
    }
}
